// src/app/services/cloud-service.ts

import { Injectable } from '@angular/core';

// 定义服务器URL
let serverURL = `https://dev.fmode.cn/parse`;
if (location.protocol == "http:") {
    serverURL = `http://dev.fmode.cn:1337/parse`;
}

// 基础云对象类
export class CloudObject {
    className: string;
    id: string | undefined = undefined;
    createdAt: any;
    updatedAt: any;
    data: Record<string, any> = {};

    constructor(className: string) {
        this.className = className;
    }

    toPointer() {
        return { "__type": "Pointer", "className": this.className, "objectId": this.id };
    }

    set(json: Record<string, any>) {
        Object.keys(json).forEach(key => {
            if (["objectId", "id", "createdAt", "updatedAt"].indexOf(key) > -1) {
                return;
            }
            this.data[key] = json[key];
        });
    }

    get(key: string) {
        return this.data[key] || null;
    }

    async save() {
        let method = "POST";
        let url = serverURL + `/classes/${this.className}`;

        // 更新
        if (this.id) {
            url += `/${this.id}`;
            method = "PUT";
        }

        const body = JSON.stringify(this.data);
        const response = await fetch(url, {
            headers: {
                "content-type": "application/json;charset=UTF-8",
                "x-parse-application-id": "dev"
            },
            body: body,
            method: method,
            mode: "cors",
            credentials: "omit"
        });

        const result = await response?.json();
        if (result?.error) {
            console.error(result?.error);
        }
        if (result?.objectId) {
            this.id = result?.objectId;
        }
        return this;
    }

    async destroy() {
        if (!this.id) return;
        const response = await fetch(serverURL + `/classes/${this.className}/${this.id}`, {
            headers: {
                "x-parse-application-id": "dev"
            },
            body: null,
            method: "DELETE",
            mode: "cors",
            credentials: "omit"
        });

        const result = await response?.json();
        if (result) {
            this.id = undefined;
        }
        return true;
    }
}

// 查询类 - 实现了所有必要的查询方法
export class CloudQuery {
    className: string;
    queryParams: Record<string, any> = { where: {} };

    constructor(className: string) {
        this.className = className;
    }

    // 查询条件方法
    equalTo(key: string, value: any) {
        this.queryParams['where'][key] = value;
        return this;
    }
    
    // 设置包含关联对象
    include(...fields: string[]) {
        this.queryParams["include"] = fields.join(',');
        return this;
    }
    
    // 设置查询结果数量限制
    limit(limit: number) {
        this.queryParams["limit"] = limit;
        return this;
    }
    
    // 设置查询结果排序
    ascending(field: string) {
        this.queryParams["order"] = field;
        return this;
    }
    
    // 获取查询的第一个结果
    async first() {
        this.limit(1);
        const results = await this.find();
        return results.length > 0 ? results[0] : null;
    }
    
    // 执行查询并返回所有结果
    async find() {
        // 构建查询URL参数
        const queryString = Object.keys(this.queryParams)
            .map(key => `${key}=${encodeURIComponent(JSON.stringify(this.queryParams[key]))}`)
            .join('&');
            
        const response = await fetch(serverURL + `/classes/${this.className}?${queryString}`, {
            headers: {
                "x-parse-application-id": "dev"
            },
            method: "GET",
            mode: "cors",
            credentials: "omit"
        });
        
        const result = await response?.json();
        if (result?.error) {
            console.error(result?.error);
            return [];
        }
        
        // 将结果转换为CloudObject实例
        return result?.results?.map((item: any) => {
            const obj = new CloudObject(this.className);
            obj.id = item.objectId;
            obj.createdAt = item.createdAt;
            obj.updatedAt = item.updatedAt;
            obj.data = { ...item };
            delete obj.data['objectId'];
            delete obj.data['createdAt'];
            delete obj.data['updatedAt'];
            return obj;
        }) || [];
    }
}

// 云服务类
@Injectable({
    providedIn: 'root'
})
export class CloudService {
    constructor() { }
}