// src/app/services/crm-service.ts

import { Injectable } from '@angular/core';
import { CloudObject, CloudQuery } from './cloud-service';

// 客户数据模型
export class Client extends CloudObject {
    constructor() {
        super('Client'); // 对应后端的Client类
    }
    
    // 设置客户属性的便捷方法
    setClientData(data: {
        clientId: string;
        clientName: string;
        clientType: string;
        chatData: string;
        date: string;
    }) {
        this.set({
            clientId: data.clientId,
            clientName: data.clientName,
            clientType: data.clientType,
            chatData: data.chatData,
            date: data.date
        });
    }
    
    // 获取客户属性的便捷方法
    getClientData() {
        return {
            clientId: this.get('clientId'),
            clientName: this.get('clientName'),
            clientType: this.get('clientType'),
            chatData: this.get('chatData'),
            date: this.get('date')
        };
    }
}

// 聊天消息数据模型 - 添加了必要的属性定义
export class ChatMessage extends CloudObject {
    constructor() {
        super('ChatMessage'); // 对应后端的ChatMessage类
    }
    
    // 设置消息属性
    setMessageData(data: {
        clientId: string;
        time: string;
        sender: string;
        content: string;
    }) {
        this.set({
            clientId: data.clientId,
            time: data.time,
            sender: data.sender,
            content: data.content
        });
    }
    
    // 添加获取属性的方法
    getTime() { return this.get('time'); }
    getSender() { return this.get('sender'); }
    getContent() { return this.get('content'); }
    getClientId() { return this.get('clientId'); }
}

// CRM服务类 - 实现了所有必要的方法
@Injectable({
    providedIn: 'root'
})
export class CRMServices {
    constructor() { }
    
    // 保存客户数据到后端
    async saveClient(clientData: {
        clientId: string;
        clientName: string;
        clientType: string;
        chatData: string;
        date: string;
    }): Promise<Client> {
        // 先检查是否已有该客户ID的记录
        const query = new CloudQuery('Client');
        query.equalTo('clientId', clientData.clientId);
        const existingClient = await query.first();
        
        let client: Client;
        
        if (existingClient) {
            // 如果存在，更新现有记录
            client = new Client();
            client.id = existingClient.id;
            client.setClientData(clientData);
        } else {
            // 如果不存在，创建新记录
            client = new Client();
            client.setClientData(clientData);
        }
        
        // 保存到后端
        await client.save();
        return client;
    }
    
    // 获取所有客户
    async getAllClients(): Promise<Client[]> {
        const query = new CloudQuery('Client');
        query.limit(1000); // 设置最大查询数量
        const results = await query.find();
        return results.map((result: { id: string | undefined; get: (arg0: string) => any; }) => {
            const client = new Client();
            client.id = result.id;
            client.setClientData({
                clientId: result.get('clientId'),
                clientName: result.get('clientName'),
                clientType: result.get('clientType'),
                chatData: result.get('chatData'),
                date: result.get('date')
            });
            return client;
        });
    }
    
    // 保存聊天消息
    async saveChatMessages(clientId: string, messages: ChatMessage[]): Promise<void> {
        for (const msg of messages) {
            // 确保消息与客户关联
            msg.set({ clientId });
            await msg.save();
        }
    }
    
    // 获取客户的聊天消息
    async getChatMessages(clientId: string): Promise<ChatMessage[]> {
        const query = new CloudQuery('ChatMessage');
        query.equalTo('clientId', clientId);
        query.ascending('time'); // 按时间升序排列
        const results = await query.find();
        
        return results.map((result: { id: string | undefined; get: (arg0: string) => any; }) => {
            const msg = new ChatMessage();
            msg.id = result.id;
            msg.setMessageData({
                clientId: result.get('clientId'),
                time: result.get('time'),
                sender: result.get('sender'),
                content: result.get('content')
            });
            return msg;
        });
    }
    
    // 删除客户及其相关聊天记录
    async deleteClient(clientId: string): Promise<void> {
        // 先查找客户
        const query = new CloudQuery('Client');
        query.equalTo('clientId', clientId);
        const clients = await query.find();
        
        if (clients.length > 0) {
            // 删除客户
            await clients[0].destroy();
            
            // 删除相关的聊天记录
            const msgQuery = new CloudQuery('ChatMessage');
            msgQuery.equalTo('clientId', clientId);
            const messages = await msgQuery.find();
            
            for (const msg of messages) {
                await msg.destroy();
            }
        }
    }
}