import { Component, Input, Output, EventEmitter } from '@angular/core';
import { CommonModule } from '@angular/common';
import { Report } from './report.interface';

interface EvaluationItem {
  label: string;
  score: number;
}

@Component({
  selector: 'app-training-reports',
  standalone: true,
  imports: [CommonModule],
  template: `
    <div class="training-reports">
      <h2>训练报告</h2>
      
      <div class="report-list">
        <div *ngFor="let report of reports" 
             class="report-card"
             (click)="selectReport(report)">
          <div class="report-header">
            <h3>{{report.name}}</h3>
            <span>{{report.date | date:'yyyy-MM-dd HH:mm'}}</span>
          </div>
          <div class="report-meta">
            <span>难度: {{getDifficultyLabel(report.difficulty)}}</span>
            <span>角色: {{report.customerRole}}</span>
            <span class="score-badge">得分: {{report.score || 0}}/100</span>
          </div>
        </div>
      </div>

      <div *ngIf="selectedReport" class="modal-overlay" (click)="closeReport($event)">
        <div class="modal-content" (click)="$event.stopPropagation()">
          <div class="report-detail">
            <div class="detail-header">
              <h2>{{selectedReport.name}}</h2>
              <button class="close-btn" (click)="closeReport()">×</button>
            </div>
            <div class="detail-meta">
              <span><strong>日期:</strong> {{selectedReport.date | date:'yyyy-MM-dd HH:mm'}}</span>
              <span><strong>难度:</strong> {{getDifficultyLabel(selectedReport.difficulty)}}</span>
              <span><strong>角色:</strong> {{selectedReport.customerRole}}</span>
              <span><strong>总分:</strong> {{selectedReport.score || 0}}/100</span>
            </div>
            
            <div class="detail-evaluations">
              <h3>能力评估</h3>
              <div class="eval-grid">
                <div *ngFor="let eval of getEvaluations(selectedReport)" class="eval-card">
                  <div class="eval-score">{{eval.score}}</div>
                  <div class="eval-label">{{eval.label}}</div>
                  <div class="progress-bar">
                    <div class="progress-fill" [style.width.%]="eval.score"></div>
                  </div>
                </div>
              </div>
            </div>
            
            <div class="detail-summary">
              <h3>训练总结</h3>
              <p>{{selectedReport.summary}}</p>
            </div>
          </div>
        </div>
      </div>
    </div>
  `,
  styles: [`
    .training-reports {
      padding: 20px;
      max-width: 1200px;
      margin: 0 auto;
    }
    
    .report-list {
      display: grid;
      gap: 15px;
    }
    
    .report-card {
      background: white;
      border-radius: 8px;
      padding: 15px;
      cursor: pointer;
      transition: all 0.2s ease;
      box-shadow: 0 2px 4px rgba(0,0,0,0.1);
      border-left: 4px solid #4CAF50;
    }
    
    .report-card:hover {
      transform: translateY(-2px);
      box-shadow: 0 4px 8px rgba(0,0,0,0.15);
    }
    
    .report-header {
      display: flex;
      justify-content: space-between;
      align-items: center;
      margin-bottom: 10px;
    }
    
    .report-header h3 {
      margin: 0;
      color: #333;
    }
    
    .report-meta {
      display: flex;
      gap: 15px;
      color: #666;
      font-size: 0.9rem;
      flex-wrap: wrap;
    }
    
    .score-badge {
      background: #4CAF50;
      color: white;
      padding: 2px 8px;
      border-radius: 12px;
      font-size: 0.8rem;
    }
    
    .modal-overlay {
      position: fixed;
      top: 0;
      left: 0;
      right: 0;
      bottom: 0;
      background: rgba(0,0,0,0.5);
      display: flex;
      justify-content: center;
      align-items: center;
      z-index: 1000;
    }
    
    .modal-content {
      background: white;
      border-radius: 8px;
      width: 90%;
      max-width: 800px;
      max-height: 90vh;
      overflow: auto;
      box-shadow: 0 4px 20px rgba(0,0,0,0.2);
    }
    
    .report-detail {
      padding: 25px;
    }
    
    .detail-header {
      display: flex;
      justify-content: space-between;
      align-items: center;
      margin-bottom: 20px;
      border-bottom: 1px solid #eee;
      padding-bottom: 15px;
    }
    
    .detail-header h2 {
      margin: 0;
      color: #333;
    }
    
    .close-btn {
      background: none;
      border: none;
      font-size: 24px;
      cursor: pointer;
      color: #666;
    }
    
    .detail-meta {
      display: flex;
      flex-wrap: wrap;
      gap: 15px;
      margin-bottom: 20px;
      color: #555;
    }
    
    .detail-meta span {
      display: flex;
      align-items: center;
      gap: 5px;
    }
    
    .detail-meta strong {
      color: #333;
    }
    
    .eval-grid {
      display: grid;
      grid-template-columns: repeat(auto-fit, minmax(150px, 1fr));
      gap: 15px;
      margin-top: 15px;
    }
    
    .eval-card {
      background: #f8f9fa;
      border-radius: 8px;
      padding: 15px;
      text-align: center;
    }
    
    .eval-score {
      font-size: 28px;
      font-weight: bold;
      color: #333;
      margin-bottom: 5px;
    }
    
    .eval-label {
      color: #666;
      font-size: 0.9rem;
      margin-bottom: 10px;
    }
    
    .progress-bar {
      height: 6px;
      background: #e0e0e0;
      border-radius: 3px;
      overflow: hidden;
    }
    
    .progress-fill {
      height: 100%;
      background: #4CAF50;
      transition: width 0.3s ease;
    }
    
    .detail-summary {
      margin-top: 25px;
      padding-top: 20px;
      border-top: 1px solid #eee;
    }
    
    .detail-summary h3 {
      color: #333;
      margin-top: 0;
    }
    
    .detail-summary p {
      line-height: 1.6;
      color: #444;
    }
  `]
})
export class TrainingReportsComponent {
  @Input() reports: Report[] = [];
  @Output() reportSelected = new EventEmitter<Report>();

  selectedReport: Report | null = null;

  getDifficultyLabel(difficulty: string): string {
    const labels: Record<string, string> = {
      'easy': '初级',
      'medium': '中级',
      'hard': '高级',
      'expert': '专家级'
    };
    return labels[difficulty] || difficulty;
  }

  getEvaluations(report: Report): EvaluationItem[] {
    return [
      { label: '反应力', score: report.evaluations.responsiveness },
      { label: '话术', score: report.evaluations.话术 },
      { label: '说服力', score: report.evaluations.persuasion },
      { label: '专业度', score: report.evaluations.professionalism }
    ];
  }

  selectReport(report: Report): void {
    this.selectedReport = report;
    this.reportSelected.emit(report);
  }

  closeReport(event?: MouseEvent): void {
    if (!event || (event.target as HTMLElement).classList.contains('modal-overlay')) {
      this.selectedReport = null;
    }
  }
}