import { Injectable } from '@angular/core';
import { Observable, of } from 'rxjs';
import { delay } from 'rxjs/operators';

@Injectable({
  providedIn: 'root'
})
export class TrainingService {
  // 模拟数据库
  private sceneLevels: SceneLevel[] = [
    { value: 'easy', label: '初级' },
    { value: 'medium', label: '中级' },
    { value: 'hard', label: '高级' }
  ];

  private customerTypes: CustomerType[] = [
    { value: 'new', label: '新客户' },
    { value: 'returning', label: '回头客' },
    { value: 'vip', label: 'VIP客户' },
    { value: 'complaining', label: '投诉客户' }
  ];

  private allScenes: Scene[] = [
    {
      id: 'scene-1',
      name: '产品初次介绍',
      description: '向新客户介绍公司主打产品',
      level: 'easy',
      customerType: 'new',
      initialMessage: '您好，我对贵公司的产品很感兴趣，能简单介绍一下吗？'
    },
    {
      id: 'scene-2',
      name: '处理价格异议',
      description: '应对客户对价格的质疑',
      level: 'medium',
      customerType: 'returning',
      initialMessage: '你们的产品价格比竞争对手高不少，能解释下为什么吗？'
    },
    {
      id: 'scene-3',
      name: 'VIP客户维护',
      description: '与重要客户保持良好关系',
      level: 'medium',
      customerType: 'vip',
      initialMessage: '王总，感谢您一直以来的支持，最近使用我们的产品还满意吗？'
    },
    {
      id: 'scene-4',
      name: '处理严重投诉',
      description: '解决客户重大不满问题',
      level: 'hard',
      customerType: 'complaining',
      initialMessage: '你们的产品简直太差了！我要退货并要求赔偿！'
    }
  ];

  private sampleReports: Report[] = [
    {
      id: 'report-1',
      sceneId: 'scene-1',
      sceneName: '产品初次介绍',
      date: new Date('2023-06-15').toISOString(),
      score: 88,
      evaluations: {
        responsiveness: 85,
        话术: 82,
        persuasion: 78,
        professionalism: 90
      },
      summary: '产品介绍流畅，但未能有效突出产品独特卖点'
    }
  ];

  constructor() { }

  getSceneLevels(): Observable<SceneLevel[]> {
    return of(this.sceneLevels).pipe(delay(300));
  }

  getCustomerTypes(): Observable<CustomerType[]> {
    return of(this.customerTypes).pipe(delay(300));
  }

  getAllScenes(): Observable<Scene[]> {
    return of(this.allScenes).pipe(delay(400));
  }

  getGeneratedReports(): Observable<Report[]> {
    return of(this.sampleReports).pipe(delay(500));
  }

  generateResponse(sceneId: string, userInput: string): string {
    const scene = this.allScenes.find(s => s.id === sceneId);
    if (!scene) return '我不太明白您的意思';

    // 根据场景和用户输入生成响应
    if (sceneId === 'scene-1') {
      if (userInput.includes('价格') || userInput.includes('多少钱')) {
        return '我们的产品价格区间在X到Y之间，具体取决于配置。您对哪个型号感兴趣？';
      }
      return '这款产品的核心优势是A、B、C三个功能，能有效解决您面临的X问题。';
    }
    
    if (sceneId === 'scene-4') {
      if (userInput.includes('抱歉') || userInput.includes('对不起')) {
        return '道歉是不够的！我需要你们立即解决问题！';
      }
      if (userInput.includes('方案') || userInput.includes('解决')) {
        return '我们提供三种解决方案：1. 全额退款 2. 产品更换 3. 补偿优惠券，您倾向于哪种？';
      }
      return '我理解您的不满，请给我们一个改正的机会。';
    }

    // 默认回复逻辑
    const responses = [
      '这是一个很好的观点，我们可以详细讨论。',
      '关于这个问题，我们的专业团队是这样建议的...',
      '我理解您的担忧，实际上我们的产品是这样处理的...',
      '根据大多数客户反馈，这个问题的解决方案是...'
    ];
    return responses[Math.floor(Math.random() * responses.length)];
  }
}

// 数据模型
export interface SceneLevel {
  value: string;
  label: string;
}

export interface CustomerType {
  value: string;
  label: string;
}

export interface Scene {
  id: string;
  name: string;
  description: string;
  level: string;
  customerType: string;
  initialMessage: string;
}

export interface Report {
  id: string;
  sceneId: string;
  sceneName: string;
  date: string;
  score: number;
  evaluations: {
    responsiveness: number;
    话术: number;
    persuasion: number;
    professionalism: number;
  };
  summary: string;
}